| boundary | R Documentation |
Extracts the decision boundary from a fitted projective Bayes classifier. The decision boundary consists of the minimal set of feature combinations that are classified as positive (1), i.e., combinations classified as 1 for which no combination lower in the partial ordering is also classified as 1. Any feature combination at or above a boundary combination in the partial ordering is guaranteed to be classified as 1, making the boundary the most compact representation of the classification rule.
boundary(object)
object |
a fitted object of class |
A list of class "boundary" containing the following
components:
a numeric matrix of feature combinations forming the
decision boundary, where each row is one minimal positive combination.
NULL if no combinations are classified as 1.
a binary numeric vector giving the classification of each boundary combination (all values will be 1)
a numeric vector of posterior probabilities at each boundary combination
an integer giving the number of boundary combinations
an integer giving the total number of combinations classified as 1
an integer giving the total number of unique feature combinations
Cheung YK, Diaz KM. Monotone response surface of multi-factor condition: estimation and Bayes classifiers. J R Stat Soc Series B Stat Methodol. 2023 Apr;85(2):497-522. doi: 10.1093/jrsssb/qkad014. Epub 2023 Mar 22. PMID: 38464683; PMCID: PMC10919322.
Cheung YK, Kuhn L. Evaluating multiplex diagnostic test using partially ordered Bayes classifier. Ann Appl Stat. In press.
A <- as.matrix(expand.grid(rep(list(0:1), 6)))
set.seed(2025)
X <- A[sample(nrow(A), size=500, replace=TRUE),]
y <- as.numeric(rowSums(X) >= 3)
fit <- PBclassifier(X, y)
db <- boundary(fit)
print(db)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.